@@ -136,7 +136,7 @@ int main(int argc, char *argv[])
 #endif
 
 	/* process commandline {{{ */
-	while ((ch = getopt(argc, argv, "f:H:T:hqlrs:pd:")) != -1)
+	while ((ch = getopt(argc, argv, "f:H:T:hvqlrs:pd:")) != -1)
 	{
 		switch(ch)
 		{
@@ -197,8 +197,13 @@ int main(int argc, char *argv[])
 					cf.refresh_delay = x;
 				break;
 
-			case 'h': 
-			case '?': 
+			case 'v':
+				version();
+				exit(0);
+				break;
+
+			case 'h':
+			case '?':
 				usage();
 				exit(1);
 				break;
@@ -237,7 +242,7 @@ int main(int argc, char *argv[])
 			hc->create(cf.circle_size);
 			c = hc;
 			break;
-	
+
 		case TIMED_CIRCLE:
 			tc = new Timed_Circle;
 			tc->create(cf.circle_size);
@@ -263,15 +268,15 @@ int main(int argc, char *argv[])
 	rm->create(cf.circle_size);
 
 	/* ip string -> ip hash map */
-	im = new map; 
+	im = new map;
 	im->create(cf.circle_size);
 
 	/* host string -> host hash map */
-	hm = new map; 
+	hm = new map;
 	hm->create(cf.circle_size);
 	/* }}} */
 
-	memset(&gstats, (char) NULL, sizeof(gstats));
+	memset(&gstats, 0, sizeof(gstats));
 	gstats.start = time(NULL);
 
 	signal(SIGINT, &catchsig);
@@ -391,7 +396,7 @@ int main(int argc, char *argv[])
 			*/
 			curfile = (struct input *)fe.userdata;
 			fd = curfile->fd;
-			
+
 /* }}} */
 #else /* fallback to stat() {{{ */
 
@@ -414,7 +419,7 @@ int main(int argc, char *argv[])
 				close(fd);
 				curfile->fd = 0;
 				curfile->open = false;
-				
+
 				/* skip rest of loop, we'll try
 				 * to reopen at top of for(;;) */
 				continue;
@@ -443,7 +448,7 @@ int main(int argc, char *argv[])
 			{
 				/* this should only happen if we've had to
 				 * fall back to stat() */
-				continue; 
+				continue;
 			}
 
 			if (buflen < 0) /* error */
@@ -465,7 +470,7 @@ int main(int argc, char *argv[])
 					continue;
 				}
 
-				*nextline = (char) NULL;
+				*nextline = '\0';
 				++nextline;
 
 				/* which parser? */
@@ -485,7 +490,7 @@ int main(int argc, char *argv[])
 				{
 					/* record which file the log is from */
 					lb.fileid = fd;
-				
+
 					/* insert into circle */
 					c->insert(lb);
 
@@ -505,6 +510,7 @@ int main(int argc, char *argv[])
 
 	} /* for( ;; ) */
 
+	delete cmmp;
 	endwin();
 
 	return 0;
@@ -584,7 +590,7 @@ int read_key(int ch) /* {{{ */
 			cf.in_submenu = SUBMENU_DISP;
 			cf.in_submenu_time = now;
 			cf.in_submenu_stay = false;
-			
+
 			/* display banner to aid further presses */
 			display_submenu_banner(SUBMENU_DISP_TITLE,
 			    sizeof(SUBMENU_DISP_TITLE), SUBMENU_DISP_BANNER);
@@ -611,7 +617,7 @@ int read_key(int ch) /* {{{ */
 
 			/* don't blat it */
 			cf.display_paused = true;
-			
+
 			display_help();
 
 			break;
@@ -630,13 +636,13 @@ int read_key(int ch) /* {{{ */
 				cf.do_immed_display = true;
 			}
 			break;
-	
+
 		case ' ':
 			cf.do_immed_display = true;
 			break;
 
 #if 0
-		case 's': /* new refresh delay */ 
+		case 's': /* new refresh delay */
 #ifndef SOLARIS /* linking against readline is failing on Solaris atm */
 			endwin();
 			char *t;
@@ -728,7 +734,7 @@ int read_key(int ch) /* {{{ */
 				cf.do_immed_display = true;
 			}
 			break;
-		
+
 		case KEY_REFRESH:
 			refresh();
 			break;
@@ -802,7 +808,7 @@ int read_key(int ch) /* {{{ */
 			case 'i':
 				cf.detail_display_hosts = !cf.detail_display_hosts;
 				break;
-		
+
 		}
 		cf.in_submenu = SUBMENU_NONE;
 		clear_submenu_banner();
@@ -853,13 +859,13 @@ int read_key(int ch) /* {{{ */
 
 			/* don't blat it */
 			cf.display_paused = true;
-			
+
 			/* and render the page; similar to display_help();
 			 * this calls functions in the Filter class to do
 			 * its work */
 			display_active_filters();
 
-			
+
 			break;
 
 	} /* }}} */
@@ -873,7 +879,7 @@ int read_key(int ch) /* {{{ */
 			case 'u': case 'r': case 'h':
 				/* it was */
 				break;
-		
+
 			default:
 				cf.in_submenu = SUBMENU_NONE;
 				cf.in_submenu_stay = false;
@@ -1038,9 +1044,14 @@ int new_file(const char *filename, bool do_seek_to_end) /* {{{ */
 	return 0;
 } /* }}} */
 
+void version(void) /* {{{ */
+{
+	fprintf(stdout, "ApacheTop %s\n", PACKAGE_VERSION);
+} /* }}} */
+
 void usage(void) /* {{{ */
 {
-	fprintf(stderr, 
+	fprintf(stderr,
 	    "ApacheTop v%s - Usage:\n"
 	    "File options:\n"
 	    "  -f logfile  open logfile (assumed common/combined) [%s]\n"
@@ -1060,9 +1071,10 @@ void usage(void) /* {{{ */
 	    "\n"
 	    "  -d secs     refresh delay in seconds [%d]\n"
 	    "\n"
+	    "  -v          show version\n"
 	    "  -h          this help\n"
 	    "\n"
-	    "Compile Options: %cHAVE_KQUEUE %cHAVE_FAM %cENABLE_PCRE\n"
+	    "Compile Options: %cHAVE_KQUEUE %cHAVE_FAM %cENABLE_PCRE2\n"
 	    "Polling Method: %s\n"
 	    ,
 	    PACKAGE_VERSION,
@@ -1084,7 +1096,7 @@ void usage(void) /* {{{ */
 #else
 	    '-',
 #endif /* }}} */
-#if HAVE_PCRE_H /* {{{ */
+#if HAVE_PCRE2_H /* {{{ */
 	    '+',
 #else
 	    '-',
@@ -1094,7 +1106,7 @@ void usage(void) /* {{{ */
 	            "stat"
 		)
 	    )
-	    
+
 	    );
 
 	return;
@@ -1110,7 +1122,7 @@ int dprintf(const char *fmt, ...) /* {{{ */
       	{
         	strcpy( fileName, "/tmp/atop.XXXXXX" );
         	mkdtemp( fileName );
-        	strncat( fileName, "/debug", sizeof(fileName ) );
+        	strncat( fileName, "/debug", sizeof(fileName) - strlen(fileName) - 1 );
        	}
 
         if (cf.debug && (d = fopen(fileName, "a")))
