@@ -2,7 +2,7 @@
 
 Filter::Filter(void)
 {
-#if HAVE_PCRE_H_ 
+#if HAVE_PCRE2_H
 	regexp = NULL;
 #endif
 	filter_text = NULL;
@@ -20,9 +20,18 @@ void Filter::store(const char *filter)
 	if (filter_text) free(filter_text);
 	filter_text = strdup(filter);
 
-#if HAVE_PCRE_H_
+#if HAVE_PCRE2_H
 	if (regexp) delete regexp;
-	regexp = new RegEx(filter);
+	try
+	{
+		regexp = new RegEx(filter);
+		regex_isvalid = true;
+	}
+	catch (int err)
+	{
+		regexp = NULL;
+		regex_isvalid = false;
+	}
 #endif
 
 	return;
@@ -40,17 +49,17 @@ bool Filter::match(const char *string)
 	if (!filter_text)
 		return false;
 
-#if HAVE_PCRE_H_
-	return regexp->Search(string);
-#else
-	return strstr(string, filter_text);
+#if HAVE_PCRE2_H
+	if (regex_isvalid)
+		return regexp->Search(string);
 #endif
+	return strstr(string, filter_text);
 }
 
 
 void Filter::empty(void)
 {
-#if HAVE_PCRE_H_ 
+#if HAVE_PCRE2_H
 	if (regexp) delete regexp;
 	regexp = NULL;
 #endif
