@@ -22,7 +22,7 @@ private:
 	double rc_summary[6];
 
 	typedef struct logbits circle_struct;
-	struct circle_struct *tab;
+	circle_struct *tab;
 	int size; /* total size of circle table */
 	int pos; /* where are we now? */
 
